;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "persistent-soft" "20250805.1017"
  "Persistent storage, returning nil on failure."
  '((pcache     "0.3.1")
    (list-utils "0.4.2"))
  :url "http://github.com/rolandwalker/persistent-soft"
  :commit "24e41d1952bef5953ef0af2288de146265c7ee10"
  :revdesc "24e41d1952be"
  :keywords '("data" "extensions")
  :authors '(("Roland Walker" . "walker@pobox.com"))
  :maintainers '(("Roland Walker" . "walker@pobox.com")))
